@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2008  Michel de Boer <michel@twinklephone.com>
+    Copyright (C) 2005-2009  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "audio_device.h"
@@ -89,7 +88,7 @@ bool t_audio_io::open(const string& device, bool playback, bool capture, bool bl
 	return true;
 }
 
-t_oss_io::t_oss_io() : fd(-1), rec_buffersize(0), play_buffersize(0) {
+t_oss_io::t_oss_io() : fd(-1), play_buffersize(0), rec_buffersize(0) {
 }
 
 t_oss_io::~t_oss_io()
@@ -338,6 +337,10 @@ int t_oss_io::get_buffer_size(bool is_recording_buffer)
 	else return play_buffersize;
 }
 
+bool t_oss_io::play_buffer_underrun(void) {
+	return get_buffer_space(false) >= get_buffer_size(false);
+}
+
 
 int t_oss_io::read(unsigned char* buf, int len) {
 	return ::read(fd, buf, len);
@@ -386,7 +389,6 @@ bool t_alsa_io::open(const string& device, bool playback, bool capture, bool blo
 		short_latency);
 		
 	int mode = 0;
-	int status;
 	string msg;
 	
 	this->short_latency = short_latency;
@@ -731,7 +733,7 @@ int t_alsa_io::get_buffer_space(bool is_recording_buffer) {
 		// rv = rec_framesize * snd_pcm_status_get_avail_max(status);
 		
 		snd_pcm_hwsync(pcm_rec_ptr);
-		if (err = snd_pcm_delay(pcm_rec_ptr, &delay) < 0) {
+		if ((err = snd_pcm_delay(pcm_rec_ptr, &delay)) < 0) {
 			string msg = "snd_pcm_delay for capture buffer failed: ";
 			msg += snd_strerror(err);
 			log_file->write_report(msg, "t_alsa_io::get_buffer_space", 
@@ -771,6 +773,11 @@ int t_alsa_io::get_buffer_size(bool is_recording_buffer)
 	else return play_buffersize;
 }
 
+bool t_alsa_io::play_buffer_underrun(void) {
+	if (!pcm_play_ptr) return false;
+	return snd_pcm_state(pcm_play_ptr) == SND_PCM_STATE_XRUN;
+}
+
 int t_alsa_io::read(unsigned char* buf, int len) {
 	string msg;
 	
