@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2008  Michel de Boer <michel@twinklephone.com>
+    Copyright (C) 2005-2009  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include <assert.h>
@@ -38,7 +37,46 @@ t_call_info::t_call_info() {
 	clear();
 }
 
+t_call_info::t_call_info(const t_call_info& that) {
+	*this = that;
+}
+
+t_call_info& t_call_info::operator=(const t_call_info& that) {
+	if (this != &that) {
+		// FIXME: This may deadlock if "a=b" and "b=a" are run in
+		//        parallel.  The proper solution would be to switch
+		//        to std::mutex and call std::lock(this,that).
+		t_mutex_guard x1(that.mutex);
+		t_mutex_guard x2(this->mutex);
+
+		from_uri = that.from_uri;
+		from_display = that.from_display;
+
+		from_display_override = that.from_display_override;
+
+		from_organization = that.from_organization;
+		to_uri = that.to_uri;
+		to_display = that.to_display;
+		to_organization = that.to_organization;
+		subject = that.subject;
+		dtmf_supported = that.dtmf_supported;
+		dtmf_inband = that.dtmf_inband;
+		dtmf_info = that.dtmf_info;
+		hdr_referred_by = that.hdr_referred_by;
+
+		last_provisional_reason = that.last_provisional_reason;
+
+		send_codec = that.send_codec;
+		recv_codec = that.recv_codec;
+		refer_supported = that.refer_supported;
+	}
+
+	return *this;
+}
+
 void t_call_info::clear(void) {
+	t_mutex_guard g(mutex);
+
 	from_uri.set_url("");
 	from_display.clear();
 	from_display_override.clear();
@@ -56,6 +94,8 @@ void t_call_info::clear(void) {
 }
 
 string t_call_info::get_from_display_presentation(void) const {
+	t_mutex_guard g(mutex);
+
 	if (from_display_override.empty()) {
 		return from_display;
 	} else {
@@ -227,7 +267,7 @@ void t_line::cleanup(void) {
 		call_info.clear();
 		call_history->add_call_record(call_hist_record);
 		call_hist_record.renew();
-		user_config = NULL;
+		phone_user = NULL;
 		user_defined_ringtone.clear();
 		ui->cb_line_state_changed();
 	}
@@ -265,7 +305,7 @@ void t_line::cleanup_open_pending(void) {
 		call_info.clear();
 		call_history->add_call_record(call_hist_record);
 		call_hist_record.renew();
-		user_config = NULL;
+		phone_user = NULL;
 		user_defined_ringtone.clear();
 		ui->cb_line_state_changed();
 	}
@@ -313,7 +353,7 @@ void t_line::cleanup_forced(void) {
 	call_info.clear();
 	call_history->add_call_record(call_hist_record);
 	call_hist_record.renew();
-	user_config = NULL;
+	phone_user = NULL;
 	user_defined_ringtone.clear();
 	ui->cb_line_state_changed();
 }
@@ -358,7 +398,7 @@ t_line::t_line(t_phone *_phone, unsigned short _line_number) :
 	line_number = _line_number;
 	id_invite_comp = 0;
 	id_no_answer = 0;
-	user_config = NULL;
+	phone_user = NULL;
 	user_defined_ringtone.clear();
 	keep_seized = false;
 }
@@ -409,6 +449,8 @@ void t_line::start_timer(t_line_timer timer, t_object_id did) {
 	t_tmr_line	*t;
 	t_dialog	*dialog = get_dialog(did);
 	unsigned long	dur;
+	
+	assert(phone_user);
 
 	switch(timer) {
 	case LTMR_ACK_TIMEOUT:
@@ -441,7 +483,8 @@ void t_line::start_timer(t_line_timer timer, t_object_id did) {
 		id_invite_comp = t->get_object_id();
 		break;
 	case LTMR_NO_ANSWER:
-		t = new t_tmr_line(DUR_NO_ANSWER(user_config), timer, get_object_id(), did);
+		t = new t_tmr_line(DUR_NO_ANSWER(phone_user->get_user_profile()), 
+				timer, get_object_id(), did);
 		MEMMAN_NEW(t);
 		id_no_answer = t->get_object_id();
 		break;
@@ -555,19 +598,29 @@ void t_line::stop_timer(t_line_timer timer, t_object_id did) {
 	*id = 0;
 }
 
-void t_line::invite(t_user *user, const t_url &to_uri, const string &to_display,
-		const string &subject, bool anonymous)
+void t_line::invite(t_phone_user *pu, const t_url &to_uri, const string &to_display,
+		const string &subject, bool no_fork, bool anonymous)
 {
-	invite(user, to_uri, to_display, subject, t_hdr_referred_by(), 
-			t_hdr_replaces(), t_hdr_require(), anonymous);
+	t_hdr_request_disposition hdr_request_disposition;
+	
+	if (no_fork) {
+		hdr_request_disposition.set_fork_directive(
+			t_hdr_request_disposition::NO_FORK);
+	}
+
+	invite(pu, to_uri, to_display, subject, t_hdr_referred_by(), 
+			t_hdr_replaces(), t_hdr_require(), hdr_request_disposition,
+			anonymous);
 }
 
-void t_line::invite(t_user *user, const t_url &to_uri, const string &to_display,
+void t_line::invite(t_phone_user *pu, const t_url &to_uri, const string &to_display,
 		const string &subject, const t_hdr_referred_by &hdr_referred_by,
 		const t_hdr_replaces &hdr_replaces,
-		const t_hdr_require &hdr_require, bool anonymous)
+		const t_hdr_require &hdr_require, 
+		const t_hdr_request_disposition &hdr_request_disposition,
+		bool anonymous)
 {
-	assert(user);
+	assert(pu);
 	
 	// Ignore if line is not idle
 	if (state != LS_IDLE) {
@@ -583,8 +636,10 @@ void t_line::invite(t_user *user, const t_url &to_uri, const string &to_display,
 		return;
 	}
 	
-	user_config = user;
+	phone_user = pu;
+	t_user *user_config = pu->get_user_profile();
 
+	call_info.mutex.lock();
 	call_info.from_uri = create_user_uri(); // NOTE: hide_user is not set yet
 	call_info.from_display = user_config->get_display(false);
 	call_info.from_organization = user_config->get_organization();
@@ -593,6 +648,7 @@ void t_line::invite(t_user *user, const t_url &to_uri, const string &to_display,
 	call_info.to_organization.clear();
 	call_info.subject = subject;
 	call_info.hdr_referred_by = hdr_referred_by;
+	call_info.mutex.unlock();
 	
 	try_to_encrypt = user_config->get_zrtp_enabled();
 
@@ -604,7 +660,8 @@ void t_line::invite(t_user *user, const t_url &to_uri, const string &to_display,
 	open_dialog = new t_dialog(this);
 	MEMMAN_NEW(open_dialog);
 	open_dialog->send_invite(to_uri, to_display, subject, hdr_referred_by, 
-			hdr_replaces, hdr_require, anonymous);
+			hdr_replaces, hdr_require, hdr_request_disposition,
+			anonymous);
 
 	cleanup();
 }
@@ -914,7 +971,8 @@ void t_line::recvd_success(t_response *r, t_tuid tuid, t_tid tid) {
 void t_line::recvd_redirect(t_response *r, t_tuid tuid, t_tid tid) {
 	t_dialog *d;
 	
-	assert(user_config);
+	assert(phone_user);
+	t_user *user_config = phone_user->get_user_profile();
 
 	if (active_dialog) {
 		// If an active dialog exists then non-2XX should
@@ -1028,7 +1086,8 @@ void t_line::recvd_redirect(t_response *r, t_tuid tuid, t_tid tid) {
 void t_line::recvd_client_error(t_response *r, t_tuid tuid, t_tid tid) {
 	t_dialog *d;
 	
-	assert(user_config);
+	assert(phone_user);
+	t_user *user_config = phone_user->get_user_profile();
 
 	if (active_dialog) {
 		// If an active dialog exists then non-2XX should
@@ -1232,7 +1291,8 @@ void t_line::recvd_client_error(t_response *r, t_tuid tuid, t_tid tid) {
 void t_line::recvd_server_error(t_response *r, t_tuid tuid, t_tid tid) {
 	t_dialog *d;
 
-	assert(user_config);
+	assert(phone_user);
+	t_user *user_config = phone_user->get_user_profile();
 	
 	if (active_dialog) {
 		// If an active dialog exists then non-2XX should
@@ -1402,8 +1462,8 @@ void t_line::recvd_global_error(t_response *r, t_tuid tuid, t_tid tid) {
 	recvd_redirect(r, tuid, tid);
 }
 
-void t_line::recvd_invite(t_user *user, t_request *r, t_tid tid, const string &ringtone) {
-	t_response *resp;
+void t_line::recvd_invite(t_phone_user *pu, t_request *r, t_tid tid, const string &ringtone) {
+	t_user *user_config = NULL;
 	
 	switch (state) {
 	case LS_IDLE:
@@ -1429,10 +1489,12 @@ void t_line::recvd_invite(t_user *user, t_request *r, t_tid tid, const string &r
 		}
 		*/
 		
-		assert(user);
-		user_config = user;
+		assert(pu);
+		phone_user = pu;
+		user_config = phone_user->get_user_profile();
 		user_defined_ringtone = ringtone;
 		
+		call_info.mutex.lock();
 		call_info.from_uri = r->hdr_from.uri;
 		call_info.from_display = r->hdr_from.display;
 		call_info.from_display_override = r->hdr_from.display_override;
@@ -1445,6 +1507,7 @@ void t_line::recvd_invite(t_user *user, t_request *r, t_tid tid, const string &r
 		call_info.to_display = r->hdr_to.display;
 		call_info.to_organization.clear();
 		call_info.subject = r->hdr_subject.subject;
+		call_info.mutex.unlock();
 		
 		try_to_encrypt = user_config->get_zrtp_enabled();
 
@@ -1716,7 +1779,8 @@ void t_line::timeout(t_line_timer timer, t_object_id did) {
 					"t_line::timeout");
 		
 		if (active_dialog) {
-			assert(user_config);
+			assert(phone_user);
+			t_user *user_config = phone_user->get_user_profile();
 			t_service *srv = phone->ref_service(user_config);
 			if (srv->get_cf_active(CF_NOANSWER, cf_dest)) {
 				log_file->write_report("Call redirection no answer",
@@ -1836,7 +1900,8 @@ bool t_line::match(StunMessage *r, t_tuid tuid) const {
 }
 
 bool t_line::match_replaces(const string &call_id, const string &to_tag, 
-		const string &from_tag, bool &early_matched) const
+		const string &from_tag, bool no_fork_req_disposition,
+		bool &early_matched) const
 {
 	if (active_dialog && active_dialog->match(call_id, to_tag, from_tag)) {
 		early_matched = false;
@@ -1844,10 +1909,16 @@ bool t_line::match_replaces(const string &call_id, const string &to_tag,
 	}
 
 	// RFC 3891 3
-	// And early dialog only matches when it was created by the UA
+	// An early dialog only matches when it was created by the UA
+	// As an exception to this rule we accept a match when the incoming
+	// request contained a no-fork request disposition. This disposition
+	// indicated that the request did not fork. The reason why RFC 3891 3
+	// does not allow a match is to avoid problems with forked requests.
+	// With this exception, call transfer scenario's during ringing can
+	// be implemented.
 	t_dialog *d;
-	if ((d = match_call_id_tags(call_id, to_tag, from_tag, 
-		pending_dialogs)) != NULL && d->is_call_id_owner()) 
+	if ((d = match_call_id_tags(call_id, to_tag, from_tag, pending_dialogs)) != NULL &&
+	    (d->is_call_id_owner() || no_fork_req_disposition)) 
 	{
 		early_matched = true;
 		return true;
@@ -1866,18 +1937,21 @@ void t_line::process_invite_retrans(void) {
 }
 
 string t_line::create_user_contact(const string &auto_ip) const {
-	assert(user_config);
+	assert(phone_user);
+	t_user *user_config = phone_user->get_user_profile();
 	return user_config->create_user_contact(hide_user, auto_ip);
 }
 
 string t_line::create_user_uri(void) const {
-	assert(user_config);
+	assert(phone_user);
+	t_user *user_config = phone_user->get_user_profile();
 	return user_config->create_user_uri(hide_user);
 }
 
 t_response *t_line::create_options_response(t_request *r, bool in_dialog) const
 {
-	assert(user_config);
+	assert(phone_user);
+	t_user *user_config = phone_user->get_user_profile();
 	return phone->create_options_response(user_config, r, in_dialog);
 }
 
@@ -1889,7 +1963,8 @@ void t_line::send_response(t_response *r, t_tuid tuid, t_tid tid) {
 }
 
 void t_line::send_request(t_request *r, t_tuid tuid) {
-	assert(user_config);
+	assert(phone_user);
+	t_user *user_config = phone_user->get_user_profile();
 	phone->send_request(user_config, r, tuid);
 }
 
@@ -1966,36 +2041,71 @@ t_url t_line::get_remote_target_uri(void) const {
 	return active_dialog->get_remote_target_uri();
 }
 
+t_url t_line::get_remote_target_uri_pending(void) const {
+	if (pending_dialogs.empty()) return t_url();
+	return pending_dialogs.front()->get_remote_target_uri();
+}
+
 string t_line::get_remote_target_display(void) const {
 	if (!active_dialog) return "";
 	return active_dialog->get_remote_target_display();
 }
 
+string t_line::get_remote_target_display_pending(void) const {
+	if (pending_dialogs.empty()) return "";
+	return pending_dialogs.front()->get_remote_target_display();
+}
+
 t_url t_line::get_remote_uri(void) const {
 	if (!active_dialog) return t_url();
 	return active_dialog->get_remote_uri();
 }
 
+t_url t_line::get_remote_uri_pending(void) const {
+	if (pending_dialogs.empty()) return t_url();
+	return pending_dialogs.front()->get_remote_uri();
+}
+
 string t_line::get_remote_display(void) const {
 	if (!active_dialog) return "";
 	return active_dialog->get_remote_display();
 }
 
+string t_line::get_remote_display_pending(void) const {
+	if (pending_dialogs.empty()) return "";
+	return pending_dialogs.front()->get_remote_display();
+}
+
 string t_line::get_call_id(void) const {
 	if (!active_dialog) return "";
 	return active_dialog->get_call_id();
 }
 
+string t_line::get_call_id_pending(void) const {
+	if (pending_dialogs.empty()) return "";
+	return pending_dialogs.front()->get_call_id();
+}
+
 string t_line::get_local_tag(void) const {
 	if (!active_dialog) return "";
 	return active_dialog->get_local_tag();
 }
 
+string t_line::get_local_tag_pending(void) const {
+	if (pending_dialogs.empty()) return "";
+	return pending_dialogs.front()->get_local_tag();
+}
+
 string t_line::get_remote_tag(void) const {
 	if (!active_dialog) return "";
 	return active_dialog->get_remote_tag();
 }
 
+string t_line::get_remote_tag_pending(void) const {
+	if (pending_dialogs.empty()) return "";
+	return pending_dialogs.front()->get_remote_tag();
+}
+
 bool t_line::remote_extension_supported(const string &extension) const {
 	if (!active_dialog) return false;
 	return active_dialog->remote_extension_supported(extension);
@@ -2088,10 +2198,23 @@ unsigned short t_line::get_rtp_port(void) const {
 }
 
 t_user *t_line::get_user(void) const {
+	t_user *user_config = NULL;
+	
+	if (phone_user) {
+		user_config = phone_user->get_user_profile();
+	}
+	
 	return user_config;
 }
 
+t_phone_user *t_line::get_phone_user(void) const {
+	return phone_user;
+}
+
 string t_line::get_ringtone(void) const {
+	assert(phone_user);
+	t_user *user_config = phone_user->get_user_profile();
+	
 	if (!user_defined_ringtone.empty()) {
 		// Ring tone returned by incoming call script
 		return user_defined_ringtone;
