@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2008  Michel de Boer <michel@twinklephone.com>
+    Copyright (C) 2005-2009  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "definitions.h"
@@ -25,7 +24,7 @@ t_hdr_content_length::t_hdr_content_length() : t_header("Content-Length", "l") {
 	length = 0;
 }
 
-void t_hdr_content_length::set_length(int l) {
+void t_hdr_content_length::set_length(unsigned long l) {
 	populated = true;
 	length = l;
 }
@@ -35,6 +34,6 @@ string t_hdr_content_length::encode_value(void) const {
 
 	if (!populated) return s;
 
-	s = int2str(length);
+	s = ulong2str(length);
 	return s;
 }
