@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2008  Michel de Boer <michel@twinklephone.com>
+    Copyright (C) 2005-2009  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 // Content-Length header
@@ -28,10 +27,10 @@ using namespace std;
 
 class t_hdr_content_length : public t_header {
 public:
-	int length;
+	unsigned long length;
 
 	t_hdr_content_length();
-	void set_length(int l);
+	void set_length(unsigned long l);
 
 	string encode_value(void) const;
 };
