@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include <cstdio>
@@ -24,15 +23,15 @@
 #include "socket.h"
 #include "audits/memman.h"
 
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
-#if HAVE_LINUX_TYPES_H
+#ifdef HAVE_LINUX_TYPES_H
 #include <linux/types.h>
 #endif
 
-#if HAVE_LINUX_ERRQUEUE_H
+#ifdef HAVE_LINUX_ERRQUEUE_H
 #include <linux/errqueue.h>
 #endif
 
@@ -185,7 +184,7 @@ bool t_socket_udp::select_read(unsigned long timeout) {
 }
 
 bool t_socket_udp::enable_icmp(void) {
-#if HAVE_LINUX_ERRQUEUE_H
+#ifdef HAVE_LINUX_ERRQUEUE_H
 	int enable = 1;
 	int ret = setsockopt(SOL_IP, IP_RECVERR, &enable, sizeof(int));
 	if (ret < 0) return false;
@@ -196,7 +195,7 @@ bool t_socket_udp::enable_icmp(void) {
 }
 
 bool t_socket_udp::get_icmp(t_icmp_msg &icmp) {
-#if HAVE_LINUX_ERRQUEUE_H
+#ifdef HAVE_LINUX_ERRQUEUE_H
 	int ret;
 	char buf[256];
 	
