@@ -12,14 +12,14 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include <string>
 #include <iostream>
 #include "mutex.h"
 #include "thread.h"
+#include <stdexcept>
 
 using namespace std;
 
@@ -88,3 +88,39 @@ t_mutex_guard::t_mutex_guard(t_mutex &mutex) : mutex_(mutex) {
 t_mutex_guard::~t_mutex_guard() {
 	mutex_.unlock();
 }
+
+
+///////////////////////////
+// t_rwmutex
+///////////////////////////
+
+t_rwmutex::t_rwmutex()
+{
+	int ret = pthread_rwlock_init(&_lock, nullptr);
+	if (ret != 0) throw string(
+		"t_rwmutex::t_rwmutex failed to create a r/w mutex.");
+}
+
+t_rwmutex::~t_rwmutex()
+{
+	pthread_rwlock_destroy(&_lock);
+}
+
+void t_rwmutex::lockRead()
+{
+	int err = pthread_rwlock_rdlock(&_lock);
+	if (err != 0)
+		throw std::logic_error("Mutex lock failed");
+}
+
+void t_rwmutex::lockWrite()
+{
+	int err = pthread_rwlock_wrlock(&_lock);
+	if (err != 0)
+		throw std::logic_error("Mutex lock failed");
+}
+
+void t_rwmutex::unlock()
+{
+	pthread_rwlock_unlock(&_lock);
+}
