@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 // NOTE:
@@ -25,13 +24,12 @@
 
 #include <string>
 #include <list>
-#include <cc++/config.h>
 #include "protocol.h"
 #include "sys_settings.h"
 #include "audio/audio_codecs.h"
 #include "sockets/url.h"
 #include "threads/mutex.h"
-#include "boost/regex.hpp"
+#include <regex>
 
 // Forward declaration
 class t_request;
@@ -92,10 +90,10 @@ enum t_g726_packing {
 };
 
 struct t_number_conversion {
-	boost::regex	re;
-	string		fmt;
+    string re;
+    string fmt;
 	
-	string str(void) const { return re.str() + " --> " + fmt; }
+    string str(void) const { return re + " --> " + fmt; }
 };
 
 
